image_frame

Function image_frame 

pub fn image_frame(
    img: &DynamicImage,
    canvas: &Canvas,
    fit: Fit,
) -> Result<Frame>
img as a canvas-sized frame: Stretch ignores the aspect ratio, Contain letterboxes in black, Cover crops. Lanczos3 throughout.

Errors

Fails if the resampled image does not match the canvas size.