load

Function load 

pub fn load(arg: &str, p: &mut dyn Progress) -> Result<Loaded>
Read arg and check it against the manifest when it is listed there; a file outside the manifest is used as is, with a warning.

Errors

The file cannot be read, or its size or sha256 disagrees with the manifest.