Ops
Provides standard endpoints for monitoring the health of your application.
Structs
- The response of a check.
- Associates a name with a
Checker. - Builds a status object.
- A status with no health checks
- A status with health checks
Enums
- Errors that can happen when running an ops server.
Traits
- An interface for something that can be periodically checked.
Functions
- Starts a server and serves the ops endpoints.
Type Aliases
- Result type often returned from methods that can have ops
Errors.