pub fn pick(spec: &PanelSpec, card: &CardModel) -> Result<&'static Image>Expand description
The image to install for a panel on a card.
Errors
When no candidate was decided by the chip or a tested entry, or two rank alike; the message is the ranking.