pub fn resolve(arg: &str) -> Result<Resolved>Expand description
A manifest name to the archive or the cache; anything else is a path.
A path is matched to the manifest by file name. The archive is relative to the working directory, the repository root when the commands run as documented.
Errors
A manifest name whose file is in neither place.