pub fn snapshot(
ctx: &Ctx,
dir: &str,
index: u16,
wait: u64,
p: &mut dyn Progress,
) -> Result<()>Expand description
Capture everything we know how to restore into a directory.
Errors
Fails if the card does not answer or the files cannot be written.