pub fn install(
ctx: &Ctx,
image: &str,
commit: bool,
partition: Partition,
timeout_s: u64,
chunk_delay_us: u64,
wait: u64,
p: &mut dyn Progress,
) -> Result<()>Expand description
Install a firmware image through SDRAM staging and wait for the card to
report done. image is a manifest name or a path (crate::firmware).
Errors
Fails if the image is not what the manifest says, does not match what the card expects, if the card does not support SDRAM staging, or if programming does not complete in time.